@@ -27,17 +27,20 @@
 #include <unistd.h>
 #include <fcntl.h>
 
+#ifndef ATTRIBUTE_UNUSED
+#define ATTRIBUTE_UNUSED __attribute__ ((__unused__))
+#endif
 /*
  *  version.h
  */
 
 #define SND_LIB_MAJOR		0
 #define SND_LIB_MINOR		5
-#define SND_LIB_SUBMINOR	8
+#define SND_LIB_SUBMINOR	9
 #define SND_LIB_VERSION		((SND_LIB_MAJOR<<16)|\
 				 (SND_LIB_MINOR<<8)|\
 				  SND_LIB_SUBMINOR)
-#define SND_LIB_VERSION_STR	"0.5.8"
+#define SND_LIB_VERSION_STR	"0.5.9"
 
 /* OBSOLETE DEFINES WHICH WON'T BE IN 0.3.0 FINAL!!! */
 #define SOUNDLIB_VERSION_MAJOR		SND_LIB_MAJOR
@@ -596,11 +599,13 @@ void snd_seq_ev_schedule_real(snd_seq_event_t *ev, int q, int relative,
 /* set event priority (optional) */
 void snd_seq_ev_set_priority(snd_seq_event_t *ev, int high_prior);
 
-/* set event data type - following two macros are exclusive */
+/* set event data type - following three macros are exclusive */
   /* fixed size event */
 void snd_seq_ev_set_fixed(snd_seq_event_t *ev);
   /* variable size event */
 void snd_seq_ev_set_variable(snd_seq_event_t *ev, int len, void *ptr);
+  /* variable size event - user memory space */
+void snd_seq_ev_set_varusr(snd_seq_event_t *ev, int len, void *ptr);
 
 /* set queue control event data */
 /* destination is overwritten to Timer port (0:0) */
@@ -849,8 +854,6 @@ int snd_instr_iwffff_free(snd_instr_iwffff_t *iwffff);
 }
 #endif
 
-#define UNUSED __attribute__ ((unused))
-
 /*
  *
  */
